.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`util`
===================
.. automodule:: skimage.util

.. currentmodule:: skimage.util
.. autosummary::

   skimage.util.img_as_float32
   skimage.util.img_as_float64
   skimage.util.img_as_float
   skimage.util.img_as_int
   skimage.util.img_as_uint
   skimage.util.img_as_ubyte
   skimage.util.img_as_bool
   skimage.util.dtype_limits
   skimage.util.view_as_blocks
   skimage.util.view_as_windows
   skimage.util.pad
   skimage.util.crop
   skimage.util.montage
   skimage.util.montage2d
   skimage.util.random_noise
   skimage.util.regular_grid
   skimage.util.regular_seeds
   skimage.util.apply_parallel
   skimage.util.invert
   skimage.util.unique_rows



img_as_float32
--------------

.. autofunction:: skimage.util.img_as_float32

img_as_float64
--------------

.. autofunction:: skimage.util.img_as_float64

img_as_float
------------

.. autofunction:: skimage.util.img_as_float

img_as_int
----------

.. autofunction:: skimage.util.img_as_int

img_as_uint
-----------

.. autofunction:: skimage.util.img_as_uint

img_as_ubyte
------------

.. autofunction:: skimage.util.img_as_ubyte

img_as_bool
-----------

.. autofunction:: skimage.util.img_as_bool

dtype_limits
------------

.. autofunction:: skimage.util.dtype_limits

view_as_blocks
--------------

.. autofunction:: skimage.util.view_as_blocks

view_as_windows
---------------

.. autofunction:: skimage.util.view_as_windows

pad
---

.. autofunction:: skimage.util.pad

crop
----

.. autofunction:: skimage.util.crop

montage
-------

.. autofunction:: skimage.util.montage

montage2d
---------

.. autofunction:: skimage.util.montage2d

random_noise
------------

.. autofunction:: skimage.util.random_noise

regular_grid
------------

.. autofunction:: skimage.util.regular_grid

regular_seeds
-------------

.. autofunction:: skimage.util.regular_seeds

apply_parallel
--------------

.. autofunction:: skimage.util.apply_parallel

invert
------

.. autofunction:: skimage.util.invert

unique_rows
-----------

.. autofunction:: skimage.util.unique_rows

